@@ -1,7 +1,7 @@
 package PlugAuth;
 
 # ABSTRACT: Pluggable authentication and authorization server.
-our $VERSION = '0.22_01'; # VERSION
+our $VERSION = '0.12'; # VERSION
 
 
 use strict;
@@ -128,14 +128,11 @@ sub startup
     
   if(@refresh > 0 )
   {
-    $self->hook(before_dispatch => sub {
-      $_->refresh for @refresh;
-    });
     $self->helper(refresh => sub { $_->refresh for @refresh; 1 });
   }
   else
   {
-    $self->helper(refresh => sub { 1; });
+    $self->helper(refresh => sub { 1 });
   }
     
   $self->helper(welcome => sub {
@@ -176,8 +173,8 @@ sub startup
 
 1;
 
-
 __END__
+
 =pod
 
 =head1 NAME
@@ -186,7 +183,7 @@ PlugAuth - Pluggable authentication and authorization server.
 
 =head1 VERSION
 
-version 0.22_01
+version 0.12
 
 =head1 SYNOPSIS
 
@@ -412,4 +409,3 @@ This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
 
 =cut
-
