@@ -1,13 +1,14 @@
 package PlugAuth::Plugin::FlatAuth;
 
 # ABSTRACT: Authentication using Flat Files for PlugAuth
-our $VERSION = '0.22_01'; # VERSION
+our $VERSION = '0.12'; # VERSION
 
 
 use strict;
 use warnings;
 use v5.10;
 use Log::Log4perl qw( :easy );
+use Fcntl qw( :flock );
 # TODO: maybe optionally use Crypt::Passwd::XS instead
 use Crypt::PasswdMD5 qw( unix_md5_crypt apache_md5_crypt );
 use Role::Tiny::With;
@@ -67,14 +68,14 @@ sub _validate_pw
 }
 
 sub check_credentials {
-  my ($self, $user,$pw) = @_;
+  my ($class, $user,$pw) = @_;
   $user = lc $user;
 
   if($pw && $Userpw{$user})
   {
     return 1 if grep { _validate_pw($pw, $_) } @{ $Userpw{$user} };
   }
-  return $self->deligate_check_credentials($user, $pw);
+  return $class->deligate_check_credentials($user, $pw);
 }
 
 
@@ -90,16 +91,14 @@ sub _created_encrypted_password
   apache_md5_crypt($plain, $salt);
 }
 
-sub create_user { goto &create_user_cb }
-
-sub create_user_cb
+sub create_user
 {
-  my($self, $user, $password, $cb) = @_;
+  my($class, $user, $password) = @_;
 
   unless($user && $password)
   {
     WARN "User or password not provided";
-    return 0;
+      return 0;
   }
 
   $user = lc $user;
@@ -110,17 +109,21 @@ sub create_user_cb
     return 0;
   }
 
-  foreach my $filename ($self->global_config->user_file)
+  foreach my $filename ($class->global_config->user_file)
   {
     next unless -w $filename;
 
     $password = _created_encrypted_password($password);
 
-    my $ok = $self->lock_and_update_file($filename, sub {
+    eval {
       use autodie;
-      my($fh) = @_;
 
-      my $buffer = '';
+      open my $fh, '+<', $filename;
+
+      eval { flock $fh, LOCK_EX };
+      WARN "cannot lock $filename - $@" if $@;
+
+      my $buffer;
       while(! eof $fh)
       {
         my $line = <$fh>;
@@ -128,23 +131,30 @@ sub create_user_cb
         $buffer .= "$line\n";
       }
       $buffer .= join(':', $user, $password) . "\n";
-      
-      # as a rule we don't update the data structure
-      # directly, we update the config files and let
-      # refresh do that on the next request, but in
-      # this case the callback is used to modify groups,
-      # and for that to work we need to update the 
-      # userdatabase first.
-      $Userpw{$user} = $password;
-      $cb->() if defined $cb;
-      
-      $buffer;
-    });
+            
+      seek $fh, 0, 0;
+      truncate $fh, 0;
+      print $fh $buffer;
 
-    return 0 unless $ok;
+      close $fh;
 
-    INFO "created user $user";
-    return 1;
+      # if the file is created in the same second
+      # as it is modified, then refresh might
+      # not pick up the change, unless we delete
+      # the timestatmp.
+      mark_changed($filename);
+    };
+
+    if($@)
+    {
+      ERROR "writing file $filename: $@";
+      return 0;
+    }
+    else
+    {
+      INFO "created user $user";
+      return 1;
+    }
   }
 
   ERROR "None of the user files were writable";
@@ -154,7 +164,7 @@ sub create_user_cb
 
 sub change_password
 {
-  my($self, $user, $password) = @_;
+  my($class, $user, $password) = @_;
 
   unless($user && $password)
   {
@@ -172,14 +182,18 @@ sub change_password
 
   $password = _created_encrypted_password($password);
 
-  foreach my $filename ($self->global_config->user_file)
+  foreach my $filename ($class->global_config->user_file)
   {
-    $self->lock_and_update_file($filename, sub {
+    eval {
       use autodie;
-      my($fh) = @_;
 
       my $buffer = '';
-      
+
+      open my $fh, '+<', $filename;
+
+      eval { flock $fh, LOCK_EX };
+      WARN "cannot lock $filename - $@" if $@;
+
       while(! eof $fh)
       {
         my $line = <$fh>;
@@ -194,9 +208,22 @@ sub change_password
           $buffer .= "$line\n";
         }
       }
-      
-      $buffer;
-    });
+
+      seek $fh, 0, 0;
+      truncate $fh, 0;
+      print $fh $buffer;
+
+      close $fh;
+
+    };
+
+    ERROR "modifying file $filename: $@" if $@;
+
+    # if the file is created in the same second
+    # as it is modified, then refresh might
+    # not pick up the change, unless we delete
+    # the timestatmp.
+    mark_changed($filename);
   }
 
   INFO "user password changed $user";
@@ -206,7 +233,7 @@ sub change_password
 
 sub delete_user
 {
-  my($self, $user) = @_;
+  my($class, $user) = @_;
 
   $user = lc $user;
 
@@ -216,13 +243,18 @@ sub delete_user
     return 0;
   }
 
-  foreach my $filename ($self->global_config->user_file)
+  foreach my $filename ($class->global_config->user_file)
   {
-    $self->lock_and_update_file($filename, sub {
+    eval {
       use autodie;
-      my($fh) = @_;
 
       my $buffer = '';
+
+      open my $fh, '+<', $filename;
+
+      eval { flock $fh, LOCK_EX };
+      WARN "cannot lock $filename - $@" if $@;
+
       while(! eof $fh)
       {
         my $line = <$fh>;
@@ -231,8 +263,22 @@ sub delete_user
         next if ($thisuser//'') eq $user;
         $buffer .= "$line\n";
       }
-      $buffer;
-    });
+
+      seek $fh, 0, 0;
+      truncate $fh, 0;
+      print $fh $buffer;
+
+      close $fh;
+
+    };
+
+    ERROR "modifying file $filename: $@" if $@;
+
+    # if the file is created in the same second
+    # as it is modified, then refresh might
+    # not pick up the change, unless we delete
+    # the timestatmp.
+    mark_changed($filename);
   }
 
   INFO "deleted user $user";
@@ -241,8 +287,8 @@ sub delete_user
 
 1;
 
-
 __END__
+
 =pod
 
 =head1 NAME
@@ -251,7 +297,7 @@ PlugAuth::Plugin::FlatAuth - Authentication using Flat Files for PlugAuth
 
 =head1 VERSION
 
-version 0.22_01
+version 0.12
 
 =head1 SYNOPSIS
 
@@ -320,8 +366,6 @@ Returns a list of all users.
 
 =head2 PlugAuth::Plugin::FlatAuth-E<gt>create_user( $user, $password )
 
-=head2 PlugAuth::Plugin::FlatAuth-E<gt>create_user_cb( $user, $password, $callback)
-
 Create a new user with the given password.
 
 =head2 PlugAuth::Plugin::FlatAuth-E<gt>change_password( $user, $password )
@@ -348,4 +392,3 @@ This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
 
 =cut
-
