@@ -1,7 +1,7 @@
 package PlugAuth::Plugin::FlatAuthz;
 
 # ABSTRACT: Authorization using flat files for PlugAuth
-our $VERSION = '0.22_01'; # VERSION
+our $VERSION = '0.12'; # VERSION
 
 
 use strict;
@@ -9,10 +9,10 @@ use warnings;
 use v5.10;
 use Log::Log4perl qw( :easy );
 use Text::Glob qw( match_glob );
+use Fcntl qw( :flock );
 use Clone qw( clone );
 use Role::Tiny::With;
 use File::Touch;
-use List::MoreUtils qw( uniq );
 
 with 'PlugAuth::Role::Plugin';
 with 'PlugAuth::Role::Authz';
@@ -208,7 +208,7 @@ sub users_in_group {
 
 sub create_group
 {
-  my($self, $group, $users) = @_;
+  my($class, $group, $users) = @_;
 
   unless(defined $group)
   {
@@ -224,13 +224,17 @@ sub create_group
 
   $users = '' unless defined $users;
 
-  my $filename = $self->global_config->group_file;
+  my $filename = $class->global_config->group_file;
 
-  my $ok = $self->lock_and_update_file($filename, sub {
+  eval {
     use autodie;
-    my($fh) = @_;
 
-    my $buffer = '';
+    open my $fh, '+<', $filename;
+
+    eval { flock $fh, LOCK_EX };
+    WARN "cannot lock $filename - $@" if $@;
+
+    my $buffer;
     while(! eof $fh)
     {
       my $line = <$fh>;
@@ -238,20 +242,31 @@ sub create_group
       $buffer .= "$line\n";
     }
     $buffer .= "$group : $users\n";
-    
-    $buffer;
-  });
-    
-  return 0 unless $ok;
 
-  INFO "created group $group with members $users";
-  return 1;
+    seek $fh, 0, 0;
+    truncate $fh, 0;
+    print $fh $buffer;
+
+    close $fh;
+  };
+    
+  mark_changed($filename);
+  if(my $error = $@)
+  {
+    ERROR "modifying file $filename: $@";
+    return 0;
+  }
+  else
+  {
+    INFO "created group $group with members $users";
+    return 1;
+  }
 }
 
 
 sub delete_group
 {
-  my($self, $group) = @_;
+  my($class, $group) = @_;
     
   $group = lc $group;
 
@@ -261,12 +276,18 @@ sub delete_group
     return 0;
   }
 
-  my $filename = $self->global_config->group_file;
+  my $filename = $class->global_config->group_file;
 
-  my $ok = $self->lock_and_update_file($filename, sub {
+  eval {
     use autodie;
-    my($fh) = @_;
+
     my $buffer = '';
+
+    open my $fh, '+<', $filename;
+
+    eval { flock $fh, LOCK_EX };
+    WARN "cannot lock $filename - $@" if $@;
+
     while(! eof $fh)
     {
       my $line = <$fh>;
@@ -276,19 +297,30 @@ sub delete_group
       $buffer .= "$line\n";
     }
 
-    $buffer;
-  });
+    seek $fh, 0, 0;
+    truncate $fh, 0;
+    print $fh $buffer;
 
-  return 0 unless $ok;
+    close $fh;
+  };
 
-  INFO "deleted group $group";
-  return 1;
+  mark_changed($filename);
+  if(my $error = $@)
+  {
+    ERROR "modifying file $filename: $error";
+    return 0;
+  }
+  else
+  {
+    INFO "deleted group $group";
+    return 1;
+  }
 }
 
 
 sub update_group
 {
-  my($self, $group, $users) = @_;
+  my($class, $group, $users) = @_;
 
   $group = lc $group;
     
@@ -300,125 +332,51 @@ sub update_group
 
   return 1 unless defined $users;
 
-  my $filename = $self->global_config->group_file;
+  my $filename = $class->global_config->group_file;
 
-  my $ok = $self->lock_and_update_file($filename, sub {
+  eval {
     use autodie;
-    my($fh) = @_;
 
     my $buffer = '';
+
+    open my $fh, '+<', $filename;
+
+    eval { flock $fh, LOCK_EX };
+    WARN "cannot lock $filename - $@" if $@;
+
     while(! eof $fh)
     {
       my $line = <$fh>;
       chomp $line;
-      my($thisgroup) = split /\s*:/, $line;
+      my($thisgroup, $password) = split /\s*:/, $line;
       $line =~ s{:.*$}{: $users} if lc($thisgroup) eq $group;
       $buffer .= "$line\n";
     }
-    $buffer;
-  });
-  
-  return 0 unless $ok;
-  INFO "update group $group set members to $users";
-  return 1;
-}
 
+    seek $fh, 0, 0;
+    truncate $fh, 0;
+    print $fh $buffer;
 
-sub add_user_to_group
-{
-  my($self, $group, $user) = @_;
-  $group = lc $group;
-  $user  = lc $user;
+    close $fh;
+  };
 
-  unless($group && defined $groupUser{$group})
+  mark_changed($filename);
+  if(my $error = $@)
   {
-    WARN "Group $group does not exist";
+    ERROR "modifying file $filename: $error";
     return 0;
   }
-  
-  my $new_user_list;
-  my $filename = $self->global_config->group_file;
-  
-  my $ok = $self->lock_and_update_file($filename, sub {
-    use autodie;
-    my ($fh) = @_;
-    
-    my $buffer = '';
-    while(! eof $fh)
-    {
-      my $line = <$fh>;
-      chomp $line;
-      my($thisgroup, $users) = split /\s*:\s*/, $line;
-      if(lc($thisgroup) eq $group)
-      {
-        $users = join ',', uniq (split(/\s*,\s*/, $users), $user);
-        $buffer .= "$thisgroup: $users\n";
-        $new_user_list = $users;
-      }
-      else
-      {
-        $buffer .= "$line\n";
-      }
-    }
-    
-    $buffer;
-  });
-  
-  return unless $ok;
-  INFO "update group $group set members to $new_user_list";
-  return $new_user_list;
-}
-
-
-sub remove_user_from_group
-{
-  my($self, $group, $user) = @_;
-  $group = lc $group;
-  $user  = lc $user;
-
-  unless($group && defined $groupUser{$group})
+  else
   {
-    WARN "Group $group does not exist";
-    return 0;
+    INFO "update group $group set members to $users";
+    return 1;
   }
-  
-  my $new_user_list;
-  my $filename = $self->global_config->group_file;
-  
-  my $ok = $self->lock_and_update_file($filename, sub {
-    use autodie;
-    my ($fh) = @_;
-    
-    my $buffer = '';
-    while(! eof $fh)
-    {
-      my $line = <$fh>;
-      chomp $line;
-      my($thisgroup, $users) = split /\s*:\s*/, $line;
-      if(lc($thisgroup) eq $group)
-      {
-        $users = join ',', grep { lc($_) ne $user } uniq @{ $self->users_in_group($group) };
-        $buffer .= "$thisgroup: $users\n";
-        $new_user_list = $users;
-      }
-      else
-      {
-        $buffer .= "$line\n";
-      }
-    }
-    
-    $buffer;
-  });
-  
-  return unless $ok;
-  INFO "update group $group set members to $new_user_list";
-  return $new_user_list;
 }
 
 
 sub grant
 {
-  my($self, $group, $action, $resource) = @_;
+  my($class, $group, $action, $resource) = @_;
     
   $group = lc $group;
 
@@ -436,14 +394,17 @@ sub grant
     return 1;
   }
 
-  my $filename = $self->global_config->resource_file;
+  my $filename = $class->global_config->resource_file;
 
-  my $ok = $self->lock_and_update_file($filename, sub {
+  eval {
     use autodie;
-    my($fh) = @_;
 
     my $buffer = '';
         
+    open my $fh, '+<', $filename;
+    eval { flock $fh, LOCK_EX };
+    WARN "cannot lock $filename - $@" if $@;
+        
     while(! eof $fh)
     {
       my $line = <$fh>;
@@ -451,18 +412,31 @@ sub grant
       $buffer .= "$line\n";
     }
     $buffer .= "$resource ($action) : $group\n";
-    $buffer;
-  });
-  
-  return 0 unless $ok;
-  INFO "grant $group $action $resource";
-  return 1;
+        
+    seek $fh, 0, 0;
+    truncate $fh, 0;
+    print $fh $buffer;
+
+    close $fh;
+  };
+
+  mark_changed($filename);
+  if(my $error = $@)
+  {
+    ERROR "modifying file $filename: $error";
+    return 0;
+  }
+  else
+  {
+    INFO "grant $group $action $resource";
+    return 1;
+  }
 }
 
 
 sub revoke
 {
-  my($self, $group, $action, $resource) = @_;
+  my($class, $group, $action, $resource) = @_;
     
   $group = lc $group;
 
@@ -480,13 +454,16 @@ sub revoke
     return 0;
   }
     
-  my $filename = $self->global_config->resource_file;
+  my $filename = $class->global_config->resource_file;
 
-  my $ok = $self->lock_and_update_file($filename, sub {
+  eval {
     use autodie;
-    my($fh) = @_;
 
     my $buffer = '';
+        
+    open my $fh, '+<', $filename;
+    eval { flock $fh, LOCK_EX };
+    WARN "cannot lock $filename - $@" if $@;
     while(! eof $fh)
     {
       my $line = <$fh>;
@@ -506,27 +483,45 @@ sub revoke
         $buffer .= "$line\n";
       }
     }
-    $buffer;
-  });
-  
-  return 0 unless $ok;
-  INFO "revoke $group $action $resource";
+        
+    seek $fh, 0, 0;
+    truncate $fh, 0;
+    print $fh $buffer;
+        
+    close $fh;
+    
+  };
+    
+  mark_changed($filename);
+  if(my $error = $@)
+  {
+    ERROR "modifying file $filename: $@";
+    return 0;
+  }
+  else
+  {
+    INFO "revoke $group $action $resource";
+    return 1;
+  }
+
   return 1;
 }
 
 
 sub granted
 {
-  my($self) = @_;
+  my($class) = @_;
     
-  my $filename = $self->global_config->resource_file;
+  my $filename = $class->global_config->resource_file;
     
   my @granted_list;
     
-  my $ok = $self->lock_and_read_file($filename, sub {
+  eval {
     use autodie;
-    my($fh) = @_;
-    
+        
+    open my $fh, '<', $filename;
+    eval { flock $fh, LOCK_SH };
+    WARN "cannot lock $filename - $@" if $@;
     while(! eof $fh)
     {
       my $line = <$fh>;
@@ -534,15 +529,19 @@ sub granted
       push @granted_list, "$1 ($2): $3" 
         if $line =~ m{^\s*(.*?)\s*\((.*?)\)\s*:\s*(.*?)\s*$};
     }
-  });
+        
+    close $fh;
+  };
+    
+  ERROR "error reading $filename: $@" if $@;
     
   return \@granted_list;
 }
 
 1;
 
-
 __END__
+
 =pod
 
 =head1 NAME
@@ -551,7 +550,7 @@ PlugAuth::Plugin::FlatAuthz - Authorization using flat files for PlugAuth
 
 =head1 VERSION
 
-version 0.22_01
+version 0.12
 
 =head1 SYNOPSIS
 
@@ -677,14 +676,6 @@ Update the given group, setting the set of users that belong to that
 group.  The existing group membership will be replaced with the new one.
 $users is a comma separated list of user names.
 
-=head2 PlugAuth::Plugin::FlatAuthz-E<gt>add_user_to_group( $group, $user )
-
-Add the given user to the given group.
-
-=head2 PlugAuth::Plugin::FlatAuthz-E<gt>remove_user_from_group( $group, $user )
-
-Remove the given user from the given group
-
 =head2 PlugAuth::Plugin::FlatAuthz-E<gt>grant( $group, $action, $resource )
 
 Grant the given group or user ($group) the authorization to perform the given
@@ -715,4 +706,3 @@ This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
 
 =cut
-
