@@ -5,7 +5,7 @@ use warnings;
 use Role::Tiny;
 
 # ABSTRACT: Role for PlugAuth authentication plugins
-our $VERSION = '0.22_01'; # VERSION
+our $VERSION = '0.12'; # VERSION
 
 
 requires qw( check_credentials );
@@ -22,15 +22,6 @@ sub create_user
 }
 
 
-sub _find_create_user_cb
-{
-  my $self = shift;
-  return $self if $self->can('create_user_cb');
-  my $next = $self->next_auth;
-  return $next ? $next->_find_create_user_cb : ();
-}
-
-
 sub change_password
 {
   my $next_auth = shift->next_auth;
@@ -72,8 +63,8 @@ around all_users => sub {
 
 1;
 
-
 __END__
+
 =pod
 
 =head1 NAME
@@ -82,7 +73,7 @@ PlugAuth::Role::Auth - Role for PlugAuth authentication plugins
 
 =head1 VERSION
 
-version 0.22_01
+version 0.12
 
 =head1 SYNOPSIS
 
@@ -134,15 +125,6 @@ this cannot be determined, then return an empty list.
 Create the given user with the given password.  Return 1
 on success, return 0 on failure.
 
-=head2 $plugin-E<gt>create_user_cb( $user, $password, $cb )
-
-Create user with call back.  This works like C<create_user>, but
-it calls the callback while your plugin still has a lock on the
-user database (if applicable).  If this method is implemented,
-then L<PlugAuth> can create users who belong to specific groups
-as one atomic action.  If you do not implement this method then
-the server will return 501 Not Implemented.
-
 =head2 $plugin-E<gt>change_password( $user, $password )
 
 Change the password of the given user.  Return 1 on
@@ -170,6 +152,8 @@ L<PlugAuth>,
 L<PlugAuth::Guide::Plugin>,
 L<Test::PlugAuth::Plugin::Auth>
 
+=cut
+
 =head1 AUTHOR
 
 Graham Ollis <gollis@sesda3.com>
@@ -182,4 +166,3 @@ This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
 
 =cut
-
