@@ -12,7 +12,7 @@ use File::Spec;
 use File::Touch qw( touch );
 
 # ABSTRACT: private role used by L<FlatAuth|PlugAuth::Plugin::FlatAuth> and L<FlatAuthz|PlugAuth::Plugin::FlatAuthz>.
-our $VERSION = '0.22_01'; # VERSION
+our $VERSION = '0.12'; # VERSION
 
 my %MTimes;
 
@@ -117,71 +117,10 @@ sub flat_init
   }
 }
 
-sub lock_and_update_file
-{
-  use autodie;
-  my($self, $filename, $cb) = @_;
-
-  my $buffer; 
-  
-  eval {
-    open my $fh, '+<', $filename;
-    eval { flock $fh, LOCK_EX };
-    WARN "cannot lock $filename - $@" if $@;
-  
-    $buffer = $cb->($fh);
-    
-    if(defined $buffer)
-    {
-      TRACE "updating $filename";
-      seek $fh, 0, 0;
-      truncate $fh, 0;
-      print $fh $buffer;
-    }
-    
-    mark_changed($filename);
-    close $fh;
-  };
-
-  if(my $error = $@)
-  {
-    ERROR "update $filename: $error";
-  }
-
-  return defined $buffer;
-}
-
-sub lock_and_read_file
-{
-  my($self, $filename, $cb) = @_;
-  
-  use autodie;
-  
-  my $ok = eval {
-  
-    open my $fh, '<', $filename;
-    eval { flock $fh, LOCK_SH };
-    WARN "cannot lock $filename - $@" if $@;
-  
-    my $ret  = $cb->($fh);
-    
-    close $fh;
-    
-    $ret;
-  };
-  
-  if(my $error = $@)
-  {
-    ERROR "reading $filename: $error";
-  }
-  
-  $ok;
-}
-
 1;
 
-
 __END__
+
 =pod
 
 =head1 NAME
@@ -190,7 +129,7 @@ PlugAuth::Role::Flat - private role used by L<FlatAuth|PlugAuth::Plugin::FlatAut
 
 =head1 VERSION
 
-version 0.22_01
+version 0.12
 
 =head1 SEE ALSO
 
@@ -211,4 +150,3 @@ This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
 
 =cut
-
