@@ -1,7 +1,7 @@
 package PlugAuth::Routes;
 
 # ABSTRACT: routes for plugauth
-our $VERSION = '0.22_01'; # VERSION
+our $VERSION = '0.12'; # VERSION
 
 
 # There may be external authentication for these routes, i.e. using
@@ -21,6 +21,8 @@ use List::MoreUtils qw( uniq );
 get '/'      => sub { shift->welcome } => 'index';
 get '/index' => sub { shift->welcome };
 
+ladder sub { shift->refresh };
+
 
 # Check authentication for a user (http basic auth protocol).
 get '/auth' => sub {
@@ -138,36 +140,10 @@ authorize 'accounts';
 post '/user' => sub {
   my $c = shift;
   $c->parse_autodata;
-  my $user     = $c->stash->{autodata}->{user};
+  my $user = $c->stash->{autodata}->{user};
   my $password = $c->stash->{autodata}->{password} || '';
-  my $groups   = $c->stash->{autodata}->{groups};
   delete $c->stash->{autodata};
-  
-  my $method = 'create_user';
-  my $cb;
-  
-  my $auth_plugin = $c->auth;
-  
-  if(defined $groups)
-  {
-    $method = 'create_user_cb';
-    $auth_plugin = $c->auth->_find_create_user_cb;
-    return $c->render_message('not ok', 501)
-      unless defined $auth_plugin;
-    $cb = sub {
-      foreach my $group (split /\s*,\s*/, $groups)
-      {
-        my $users = $c->app->authz->add_user_to_group($group, $user);
-        $c->app->emit(create_group => {
-          admin => $c->stash('user'),
-          group => $group,
-          users => $users,
-        });
-      }
-    };
-  }
-  
-  if($auth_plugin->$method($user, $password, $cb))
+  if($c->auth->create_user($user, $password))
   {
     $c->render_message('ok', 200);
     $c->app->emit('user_list_changed');  # deprecated, but documented in a previous version
@@ -246,8 +222,14 @@ post '/group/:group' => sub {
   my $c = shift;
   $c->parse_autodata;
   my $users = $c->stash->{autodata}->{users};
-  my $group = $c->param('group');
   delete $c->stash->{autodata};
+  my $group = $c->param('group');
+  _update_group($c,$group,$users);
+};
+
+sub _update_group
+{
+  my($c,$group,$users) = @_;
   if($c->authz->update_group($group, $users))
   {
     $c->render_message('ok',     200);
@@ -261,46 +243,28 @@ post '/group/:group' => sub {
   {
     $c->render_message('not ok', 404);
   }
-};
+}
+
 
 
 post '/group/:group/#username' => sub {
   my($c) = @_;
-  my $group = $c->stash('group');
-  my $user  = $c->stash('username');
-  if(my $users = $c->authz->add_user_to_group($group, $user))
-  {
-    $c->render_message('ok', 200);
-    $c->app->emit(update_group => {
-      admin => $c->stash('user'),
-      group => $group,
-      users => $users,
-    });
-  }
-  else
-  {
-    $c->render_message('not ok', 404);
-  }
+  my $users = $c->authz->users_in_group($c->stash('group'));
+  return $c->render_message('not ok', 404) unless defined $users;
+  push @$users, $c->stash('username');
+  my $group = $c->param('group');
+  _update_group($c,$group,join(',', uniq @$users));
 };
 
 
 del '/group/:group/#username' => sub {
   my($c) = @_;
-  my $group = $c->stash('group');
-  my $user  = $c->stash('username');
-  if(my $users = $c->authz->remove_user_from_group($group, $user))
-  {
-    $c->render_message('ok', 200);
-    $c->app->emit(update_group => {
-      admin => $c->stash('user'),
-      group => $group,
-      users => $users,
-    });
-  }
-  else
-  {
-    $c->render_message('not ok', 404);
-  }
+  my $users = $c->authz->users_in_group($c->stash('group'));
+  return $c->render_message('not ok', 404) unless defined $users;
+  my $user = $c->stash('username');
+  @$users = grep { lc $_ ne lc $user } @$users;
+  my $group = $c->param('group');
+  _update_group($c,$group,join(',', @$users));
 };
 
 
@@ -374,8 +338,8 @@ post '/user/#username' => sub {
 
 1;
 
-
 __END__
+
 =pod
 
 =head1 NAME
@@ -384,7 +348,7 @@ PlugAuth::Routes - routes for plugauth
 
 =head1 VERSION
 
-version 0.22_01
+version 0.12
 
 =head1 DESCRIPTION
 
@@ -501,12 +465,6 @@ If the PlugAuth server cannot reach itself or the delegated PlugAuth server.
 Create a user.  The C<username> and C<password> are provided autodata arguments
 (JSON, YAML, form data, etc).
 
-If supported by your authentiation plugin (requires C<create_user_cb> to be
-implemented see L<PlugAuth::Plugin::Auth> for details) You may also optionally
-include C<groups> as an autodata argument, which specifies the list of groups
-to which the new user should belong.  C<groups> should be a comma separated
-list stored as a string.
-
 Emits event 'create_user' on success
 
  $app->on(create_user => sub {
@@ -673,4 +631,3 @@ This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
 
 =cut
-
