@@ -8,13 +8,13 @@ use Test::Builder;
 use Role::Tiny ();
 use PlugAuth;
 use File::Temp qw( tempdir );
-use YAML::XS qw( DumpFile );
+use YAML qw( DumpFile );
 use base qw( Exporter );
 
 our @EXPORT = qw( run_tests );
 
 # ABSTRACT: Test a PlugAuth Authz plugin for correctness
-our $VERSION = '0.22_01'; # VERSION
+our $VERSION = '0.12'; # VERSION
 
 
 my $Test = Test::Builder->new;
@@ -317,8 +317,8 @@ sub run_tests
 
 1;
 
-
 __END__
+
 =pod
 
 =head1 NAME
@@ -327,7 +327,7 @@ Test::PlugAuth::Plugin::Authz - Test a PlugAuth Authz plugin for correctness
 
 =head1 VERSION
 
-version 0.22_01
+version 0.12
 
 =head1 SYNOPSIS
 
@@ -359,4 +359,3 @@ This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
 
 =cut
-
